UdGraph

Struct UdGraph 

pub struct UdGraph<T: GraphNode> { /* private fields */ }
Undirected graph

Implementations

Source

impl<T: GraphNode> UdGraph<T>

pub fn new() -> Self

pub fn add_node(&mut self, node: T) -> u64

pub fn add_edge(&mut self, from: T, to: T)

if any node is not in the graph, it will be added to the graph. the self to self edge adding will be ignored

pub fn add_edge_ref(&mut self, from: &T, to: &T)

pub fn nodes(&self) -> Values<'_, u64, T>

pub fn iter(&self) -> UdGraphIter<'_, T>

pub fn is_empty(&self) -> bool

pub fn get_nbs<'a>(&'a self, from: &T) -> Option<Neighbors<'a, T>>

get neighbor nodes of the node from

Source

impl<T: GraphNode> UdGraph<T>

pub fn gen_dot( &self, graph_name: &str, node_shower: impl Fn(&T) -> String, ) -> String