pub struct UdGraph<T: GraphNode> { /* private fields */ }Expand description
Undirected graph
Implementations
Sourceimpl<T: GraphNode> UdGraph<T>
impl<T: GraphNode> UdGraph<T>
pub fn new() -> Self
pub fn add_node(&mut self, node: T) -> u64
Sourcepub fn add_edge(&mut self, from: T, to: T)
pub fn add_edge(&mut self, from: T, to: T)
if any node is not in the graph, it will be added to the graph. the self to self edge adding will be ignored
pub fn add_edge_ref(&mut self, from: &T, to: &T)
pub fn nodes(&self) -> Values<'_, u64, T>
pub fn iter(&self) -> UdGraphIter<'_, T> ⓘ
pub fn is_empty(&self) -> bool